@@ -8,7 +8,7 @@ from importlib import metadata
 import logging
 logger = logging.getLogger('millconnect.gui')
 
-from PyQt6.QtCore import QTimer ,QRunnable, QThreadPool, pyqtSlot, pyqtSignal, QTranslator, QLocale
+from PyQt6.QtCore import QTimer ,QRunnable, QThreadPool, pyqtSlot, pyqtSignal, QTranslator, QDir, QStandardPaths
 from PyQt6.QtWidgets import QApplication, QLabel, QWidget, QVBoxLayout, QProgressBar, QStackedWidget, QFileDialog
 from PyQt6.QtGui import QIcon
 
@@ -36,7 +36,8 @@ class ProjectSelector(QWidget):
         QTimer.singleShot(0, self.selectFolder)
 
     def selectFolder(self):
-        self.projectFolder = QFileDialog.getExistingDirectory(self, self.tr('Open project folder'))
+        defaultFolder = QDir.toNativeSeparators(QStandardPaths.writableLocation(QStandardPaths.StandardLocation.DesktopLocation))
+        self.projectFolder = QFileDialog.getExistingDirectory(self, self.tr('Open project folder'), defaultFolder)
         logger.debug(f'selected folder: "{self.projectFolder}".')
 
         if not self.projectFolder:
